==> kipi-plugins-trinity_3.5.13.2.orig.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/htmlexport/galleryinfo.cpp <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
/*
A KIPI plugin to generate HTML image galleries
Copyright 2006 by Aurelien Gateau <aurelien dot gateau at free.fr>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
// Self
#include "galleryinfo.h"

// TQt

// KDE
#include <kconfigbase.h>

// Local

namespace KIPIHTMLExport {

static const char* THEME_GROUP_PREFIX="Theme ";

TQString GalleryInfo::getThemeParameterValue(
	const TQString& theme,
	const TQString& parameter,
	const TQString& defaultValue) const
{
	TQString groupName = THEME_GROUP_PREFIX + theme;
	KConfigGroupSaver saver(config(), groupName);
	return config()->readEntry(parameter, defaultValue);
}


void GalleryInfo::setThemeParameterValue(
	const TQString& theme,
	const TQString& parameter,
	const TQString& value)
{
	// FIXME: This is hackish, but config() is const :'(
	KConfig* localConfig = const_cast<KConfig*>(config());

	TQString groupName = THEME_GROUP_PREFIX + theme;
	KConfigGroupSaver saver(localConfig, groupName);
	return localConfig->writeEntry(parameter, value);
}



} // namespace

==> kipi-plugins-trinity_14.0.8.orig.tar.xz: kipi-plugins-trinity-14.0.8/kipi-plugins/htmlexport/galleryinfo.cpp <==
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
/*
A KIPI plugin to generate HTML image galleries
Copyright 2006 by Aurelien Gateau <aurelien dot gateau at free.fr>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.

*/
// Self
#include "galleryinfo.h"

// TQt

// KDE
#include <tdeconfigbase.h>

// Local

namespace KIPIHTMLExport {

static const char* THEME_GROUP_PREFIX="Theme ";

TQString GalleryInfo::getThemeParameterValue(
	const TQString& theme,
	const TQString& parameter,
	const TQString& defaultValue) const
{
	TQString groupName = THEME_GROUP_PREFIX + theme;
	TDEConfigGroupSaver saver(config(), groupName);
	return config()->readEntry(parameter, defaultValue);
}


void GalleryInfo::setThemeParameterValue(
	const TQString& theme,
	const TQString& parameter,
	const TQString& value)
{
	// FIXME: This is hackish, but config() is const :'(
	TDEConfig* localConfig = const_cast<TDEConfig*>(config());

	TQString groupName = THEME_GROUP_PREFIX + theme;
	TDEConfigGroupSaver saver(localConfig, groupName);
	return localConfig->writeEntry(parameter, value);
}



} // namespace
